@@ -4,6 +4,19 @@
 
 """
     Microbe app
+    -----------
+
+    Create Microbe app
+
+    Settings will be loaded from settings.py if available,
+    else default settings will be loaded from default_settings.py.
+
+    If it is the first time the application is launched a 
+    symbolic link will be created in $HOME dir to themes dir :
+
+        $HOME/.microbe/themes
+
+    Admin blueprint and extensions are loaded here.
 """
 
 __author__ = 'TROUVERIE Joachim'
@@ -11,10 +24,10 @@ __author__ = 'TROUVERIE Joachim'
 import os.path as op
 from os import makedirs, symlink
 
+from flatcontent import FlatContent
 from utils import merge_default_config
 
 from flask import Flask
-from flask.ext.flatpages import FlatPages
 from flask.ext.codemirror import CodeMirror
 from flask.ext.login import LoginManager
 from flask.ext.babel import Babel
@@ -24,20 +37,18 @@ from flask.ext.themes2 import Themes
 app = Flask(__name__)
 
 # config
-path = op.join(op.dirname(__file__), 'settings.py')
-if op.exists(path) :
-    app.config.from_pyfile('settings.py')
-else :
-    app.config.from_pyfile('default_settings.py')
+app.config.from_pyfile('settings.py')
 
-# add constants in case of update
-merge_default_config(app)
+# config
+if not op.exists(app.config['SHELVE_FILENAME']) :
+    merge_default_config(app.config)
 
 # create path if not exists
 path =  op.join(op.dirname(__file__), 'content')
 if not op.exists(path) :
     makedirs(op.join(path, 'pages'))
     makedirs(op.join(path, 'posts'))
+ 
 path = op.join(op.expanduser('~'), '.microbe')
 theme_path =  op.join(op.dirname(__file__), 'themes')
 if not op.exists(path) :
@@ -45,7 +56,7 @@ if not op.exists(path) :
     symlink(theme_path, op.join(path, 'themes'))
 
 # flatpages
-pages = FlatPages(app)
+contents = FlatContent(app)
 
 # login
 lm = LoginManager()
