@@ -3,19 +3,21 @@
 # vim:set shiftwidth=4 tabstop=4 expandtab textwidth=79:
 
 """
-    Admin views for Microbe app 
+    Admin BluePrint for Microbe app 
 """
 
 __author__ = 'TROUVERIE Joachim'
 
 import os
 import os.path as op
+import shelve
 from datetime import datetime
 from itertools import chain
 from werkzeug import secure_filename
 
-from microbe import pages
-from models import Users, Content, File, Links 
+from microbe import contents
+from flatcontent import Content
+from models import Users, File, Links 
 from search import update_document, delete_document
 from utils import render_paginated
 from forms import LoginForm, UserForm, ConfigForm, ContentForm, LinkForm
@@ -26,45 +28,25 @@ from flask.ext.themes2 import get_themes_list
 from flask.ext.babel import lazy_gettext, refresh
 from flask.ext.login import login_user, logout_user, login_required
 
-
+# create blueprint
 bp = Blueprint('admin', __name__)
 
 
 def load_user(username) :
     """
-    Load user from config
+        Load user from config
+
+        :param username: user name
+        :type username: str
     """
-    # get config
-    config = current_app.config['USERS']
     return Users.get(username)
 
 
-def save_config() :
-    """
-    Save config in file
-    """
-    config = current_app.config
-    path = op.join(current_app.root_path, 'settings.py')
-    with open(path, 'w+') as config_file :
-        for key, value in config.iteritems() :
-            if isinstance(value, unicode) or isinstance(value, str):
-                content = u"{0} = u'{1}'".format(key, value)
-            elif callable(value) :
-                pass
-            else :
-                content = u"{0} = {1}".format(key, value)
-            # add new line
-            content += '\n'
-            # write
-            config_file.write(content.encode(u'utf-8'))
-
-
-
 @bp.route('/')
 @login_required
 def index() :
     """
-    Admin index view
+        Admin index view
     """
     return render_template('admin/index.html')
 
@@ -72,7 +54,10 @@ def index() :
 @bp.route('/login', methods = ['GET', 'POST'])
 def login() :
     """
-    Login view
+        Login page
+    
+        Will log the user to allow the access for 
+        blueprint views
     """
     # create form
     form = LoginForm()
@@ -86,16 +71,16 @@ def login() :
             form.password.errors.append(lazy_gettext(u'Invalid password'))
         else :
             login_user(user, remember = form.remember.data)
-            return redirect(url_for('.index'))
+            return redirect(request.args.get('next') or url_for('.index'))
     return render_template('admin/model.html', form = form, 
-            url = url_for('.login'))
+            url = '')
 
 
 @bp.route('/logout')
 @login_required
 def logout() :
     """
-    Logout user
+        Logout the current user
     """
     logout_user()
     return redirect(url_for('index'))
@@ -105,38 +90,45 @@ def logout() :
 @login_required
 def config() :
     """
-    Edit config
+        Edit app config from form
     """
     # get config
     config = current_app.config
     # populate form with config
     form = ConfigForm(
-            server_name = config.get(u'SERVER_NAME'),
-            sitename = config.get(u'SITENAME'),
-            subtitle = config.get(u'SUBTITLE'),
-            author = config.get(u'AUTHOR'),
-            language = config.get(u'LANGUAGE'),
-            pagination = config.get(u'PAGINATION'),
-            summary_length = config.get(u'SUMMARY_LENGTH'),
-            comments = config.get(u'COMMENTS'),
-            rss = config.get(u'RSS'),
-            recaptcha_public_key = config.get(u'RECAPTCHA_PUBLIC_KEY'),
-            recaptcha_private_key = config.get(u'RECAPTCHA_PRIVATE_KEY')
+            sitename = config.get('SITENAME'),
+            subtitle = config.get('SUBTITLE'),
+            author = config.get('AUTHOR'),
+            language = config.get('LANGUAGE'),
+            pagination = config.get('PAGINATION'),
+            summary_length = config.get('SUMMARY_LENGTH'),
+            comments = config.get('COMMENTS'),
+            rss = config.get('RSS'),
+            recaptcha_public_key = config.get('RECAPTCHA_PUBLIC_KEY'),
+            recaptcha_private_key = config.get('RECAPTCHA_PRIVATE_KEY')
             )
     if form.validate_on_submit() :
-        # update config
-        form.populate_obj(config)
         # refresh babel
-        if config.get(u'LANGUAGE') != current_app.config.get(u'LANGUAGE') :
+        path = current_app.config['SHELVE_FILENAME']
+        db = shelve.open(path)
+        if config.get('LANGUAGE') != db.get('LANGUAGE') :
             refresh()
-        current_app.config.update(config)
-        # save config
-        save_config()
+        db['SITENAME'] = form.sitename.data
+        db['SUBTITLE'] = form.subtitle.data
+        db['AUTHOR'] = form.author.data
+        db['LANGUAGE'] = form.language.data
+        db['PAGINATION'] = form.pagination.data
+        db['SUMMARY_LENGTH'] = form.summary_length.data
+        db['COMMENTS'] = form.comments.data
+        db['RSS'] = form.rss.data
+        db['RECAPTCHA_PUBLIC_KEY'] = form.recaptcha_public_key.data
+        db['RECAPTCHA_PRIVATE_KEY'] = form.recaptcha_private_key.data
+        db.close()
         return redirect(url_for('admin.index'))
     return render_template('admin/model.html', 
             form = form, 
             title = lazy_gettext(u'Configuration of ') + 
-            config.get(u'SITENAME'),
+            config.get('SITENAME'),
             url = url_for('.config'))
 
 
@@ -144,14 +136,16 @@ def config() :
 @login_required
 def users() :
     """
-    List users
+        List users
+
+        Available actions are edit, delete or add
     """
     # delete a user
     if request.method == 'POST' :
         user = request.form['user']
         Users.delete(user)
-        save_config()
-    users = current_app.config[u'USERS']
+        return redirect(url_for('.users'))
+    users = current_app.config['USERS']
     lst = users.keys()
     return render_paginated('admin/users.html', lst, 15, request)
 
@@ -161,7 +155,7 @@ def users() :
 @login_required
 def user(user = None) :
     """
-    Edit or create user
+        Edit or create user
     """
     # get user
     if user :
@@ -175,7 +169,6 @@ def user(user = None) :
         username = form.username.data
         pwd = form.password.data
         Users.update(username, pwd)
-        save_config()
         return redirect(url_for('.users'))
     return render_template('admin/model.html', title = title, 
             form = form, url = url_for('.user'))
@@ -184,13 +177,16 @@ def user(user = None) :
 @login_required
 def links() :
     """
-    List of links
+        List of links
+
+        Available actions are add or delete
     """
     # delete a link
     if request.method == 'POST' :
         link = request.form['link']
         Links.delete(link)
-        save_config()
+        # update config
+        return redirect(url_for('.links'))
     # get config
     lst = Links.get_all()
     links = list(chain.from_iterable(lst.values()))
@@ -201,7 +197,7 @@ def links() :
 @login_required
 def link() :
     """
-    Edit or create user
+        Create a new link
     """
     form = LinkForm()
     title = lazy_gettext(u'New link')
@@ -211,7 +207,6 @@ def link() :
         url = form.url.data
         cat = form.category.data
         Links.add(label, url, cat)
-        save_config()
         return redirect(url_for('.links'))
     return render_template('admin/model.html', title = title, 
             form = form, url = url_for('.link'))
@@ -219,11 +214,12 @@ def link() :
 
 @bp.route('/contents/', methods = ['GET', 'POST'])
 @login_required
-def contents() :
+def list_contents() :
     """
-    List posts
+        List contents
+
+        Available actions are edit, add and delete
     """
-    contents = [Content.from_page(p) for p in pages]
     # delete a content
     if request.method == 'POST' :
         path = request.form['path']
@@ -237,7 +233,6 @@ def contents() :
         # publish
         else :
             content.draft = False
-            content.published = datetime.now()
             content.save()
             update_document(content)
     # get   
@@ -253,42 +248,44 @@ def contents() :
 @login_required
 def content(path = None) :
     """
-    Edit or create post
+        Edit or create post
     """    
     # edit post
     if path :
         title = lazy_gettext(u'Edit content')
-        page = pages.get(path)
-        content = Content.from_page(page)
+        content = contents.get(path)
     else :
         content = Content()
         title = lazy_gettext(u'New content')
     # populate form
     form = ContentForm(obj = content)
     if form.validate_on_submit() :
-        form.populate_obj(content)
+        # populate obj
+        form.populate_obj(content) 
+        content.draft = True
         content.save()
         update_document(content)
-        return redirect(url_for('.contents'))
+        return redirect(url_for('.list_contents'))
     # new post
     return render_template('admin/content.html', title = title, 
-            url = url_for('.content'), form = form)
+            url = url_for('.content', path=path), form = form)
 
 
 @bp.route('/comments/<path:path>/', methods = ['GET', 'POST'])
 @login_required
 def comments(path) :
     """
-    List comments for a page
+        List comments for a content
+
+        Available action is delete
     """
     # delete a comment
     if request.method == 'POST' :
         comment = request.form['comment']
-        page = pages.get(path)
-        content = Content.from_page(page)
+        content = contents.get(path)
         content.delete_comment(comment)
     # get comments
-    page = pages.get(path)
+    page = contents.get(path)
     content = Content.from_page(page)
     comments = content.comments
     return render_paginated('admin/comments.html', comments, 15, request)
@@ -298,7 +295,7 @@ def comments(path) :
 @login_required
 def media() :
     """
-    List media available to contents
+        List media available to contents
     """
     path = op.join(op.abspath(op.dirname(__file__)), 'static', 'media')
     if not op.exists(path) :
@@ -319,7 +316,7 @@ def media() :
 @login_required
 def upload() :
     """
-    Upload new file
+        Upload new file
     """
     path = op.join(op.abspath(op.dirname(__file__)), 'static', 'media')
     fi = request.files[u'file']
@@ -344,11 +341,11 @@ def upload() :
 @login_required
 def themes() :
     """
-    List available themes
+        List available themes
     """
     current_app.theme_manager.refresh()
     themes = get_themes_list()
-    default_theme = current_app.config[u'DEFAULT_THEME']
+    default_theme = current_app.config['DEFAULT_THEME']
     selected = current_app.config.get(u'THEME', default_theme)
     return render_template('admin/themes.html', themes = themes, 
             selected = selected)
@@ -358,9 +355,12 @@ def themes() :
 @login_required
 def set_theme(ident):
     """
-    Set theme 
+        Set theme in config to be displayed to users
     """
+    path = current_app.config['SHELVE_FILENAME']
+    db = shelve.open(path)
     if ident not in current_app.theme_manager.themes :
         abort(404)
-    current_app.config.update({u'THEME' : ident})
+    db['THEME'] = ident
+    db.close()
     return redirect(url_for('.themes'))
