@@ -19,11 +19,12 @@ from flask.ext.codemirror.fields import CodeMirrorField
 from flask.ext.babel import lazy_gettext
 
 
+# required message constant
 required_message = lazy_gettext(u'This field is required')
 
 class CommentForm(Form) :
     """
-    Form to add comment to posts
+        Form to add comment to posts
     """
     name = TextField(lazy_gettext(u'Name'), 
                 [Required(message = required_message)])
@@ -33,13 +34,16 @@ class CommentForm(Form) :
 
 
 class SearchForm(Form):
+    """
+        Form to search in contents
+    """
     search = TextField(lazy_gettext(u'Search'), 
             validators = [Required()])
 
 
 class LoginForm(Form) :
     """
-    Login form
+        Login form for the admin part
     """
     username = TextField(lazy_gettext(u'User id'), 
                     [Required(message = required_message)])
@@ -50,7 +54,7 @@ class LoginForm(Form) :
 
 class ContentForm(Form) :
     """
-    Form to edit and create new post
+        Form to edit and create new post
     """
     title        = TextField(lazy_gettext(u'Title'), 
                         [Required(message = required_message)])
@@ -68,7 +72,7 @@ class ContentForm(Form) :
 
 class UserForm(Form) :
     """
-    Form to edit and add new user
+        Form to edit and add new user
     """
     username = TextField(lazy_gettext(u'Name'), 
                         [Required(message = required_message)])
@@ -84,7 +88,7 @@ class UserForm(Form) :
 
 class LinkForm(Form) :
     """
-    Link form
+        Form to add a new link object
     """
     label = TextField(lazy_gettext(u'Label'), [Required()])
     url = TextField(lazy_gettext(u'Url'), [Required()])
@@ -93,9 +97,8 @@ class LinkForm(Form) :
 
 class ConfigForm(Form) :
     """
-    Form to edit config
+        Form to edit config
     """
-    server_name    = TextField(lazy_gettext(u'Server name'))
     sitename       = TextField(lazy_gettext(u'Site name'), 
                         [Required(message = required_message)])
     subtitle       = TextField(lazy_gettext(u'Site subtitle (option)'))
@@ -115,15 +118,13 @@ class ConfigForm(Form) :
 
     def validate(self) :
         """
-        Override validation
+            Override validation
+
+            Check validation between fields
         """
         rv = Form.validate(self)
         if not rv :
             return False
-        if self.rss.data == u'YES' :
-            if not self.server_name.data :
-                error = lazy_gettext(u'Mandatory field if feeds are enabled')
-                self.server_name.errors.append(error)
         if self.comments.data == u'YES':
             if not self.recaptcha_public_key.data :
                 error = lazy_gettext(u'Mandatory field if comments are enabled')
@@ -146,15 +147,3 @@ class ConfigForm(Form) :
                     self.recaptcha_public_key.errors.append(error)
                     return False
         return True
-
-
-    def populate_obj(self, out) :
-        """
-        Override populate obj
-        """
-        meta = { key.upper() : value.data 
-                for key, value in self.__dict__.iteritems()
-                if isinstance(value, Field)
-                and key != u'crsf_token' }
-        for key, value in meta.iteritems() :
-            out[key] = value
