@@ -14,32 +14,34 @@ from whoosh.fields import Schema, TEXT, ID
 from whoosh.index import create_in
 from whoosh.qparser import QueryParser
 
-from microbe import pages
-from microbe.models import Content
+from microbe import contents
 
 # schema
 _schema = Schema(title = TEXT(stored = True), 
                  path = ID(stored = True, unique = True), 
                  content = TEXT)
+
+# global index writer
 global _ix
 
 def init_index() :
     """
-    Init the index
+        Init the index
     """
     global _ix
+    # create index writer at the launch
     path = op.join(op.dirname(__file__), 'index')
     if not op.exists(path) :
         mkdir(path)
     _ix = create_in(path, _schema)
-    for page in [Content.from_page(p) for p in pages] :
-        update_document(page)
+    for content in contents :
+        update_document(content)
 
 
 def delete_document(page) :
     """
-    Delete document
-    :param page: Content to delete
+        Delete document
+        :param page: Content to delete
     """
     # create writer
     writer = _ix.writer()
@@ -49,8 +51,8 @@ def delete_document(page) :
 
 def update_document(page) :
     """
-    Add or update a document to index
-    :param page: Content to index
+        Add or update a document to index
+        :param page: Content to index
     """
     # create writer
     writer = _ix.writer()
@@ -65,8 +67,8 @@ def update_document(page) :
 
 def search_query(query_str) :
     """
-    Search in indexed documents
-    :param query_str : Query to search in indexed components
+        Search in indexed documents
+        :param query_str: Query to search in indexed components
     """
     contents = []
     with _ix.searcher() as searcher:
@@ -78,7 +80,7 @@ def search_query(query_str) :
         # get results
         for result in results :
             path = result['path']            
-            page = pages.get(path)
+            page = contents.get(path)
             if page :
-                contents.append(Content.from_page(page))
+                contents.append(page)
         return contents
