@@ -9,26 +9,28 @@
 __author__ = 'TROUVERIE Joachim'
 
 import os.path
-from clize import clize, run
+import shelve
 from datetime import datetime
 from werkzeug.contrib.atom import AtomFeed
+from urlparse import urljoin
 
-from microbe import app, pages, babel
-from models import Content, Links
+from microbe import app, contents, babel
+from models import Links
 from forms import CommentForm, SearchForm
-from utils import get_objects_for_page, create_pagination
-from search import search_query, init_index
+from utils import render_theme_paginated
+from search import search_query 
 
-from flask import g, request, abort, url_for 
 from flask.ext.babel import format_datetime, lazy_gettext
-from flask.ext.themes2 import render_theme_template
-
+from flask.ext.themes2 import render_theme_template, static_file_url, get_theme
+from flask import (g, request, abort, url_for, make_response, 
+                  render_template, redirect)
 
 def render(template, **context):
     """
-    Render template with config theme
+        Render template with config theme
+        instead of default theme
     """
-    default = app.config[u'DEFAULT_THEME']
+    default = app.config['DEFAULT_THEME']
     theme = app.config.get(u'THEME', default)
     return render_theme_template(theme, template, **context)
 
@@ -36,7 +38,7 @@ def render(template, **context):
 @app.errorhandler(404)
 def page_not_found(e):
     """
-    Page not found error handler
+        Page not found error handler
     """
     return render('404.html'), 404
 
@@ -44,13 +46,23 @@ def page_not_found(e):
 @babel.localeselector
 def get_locale() :
     """
-    Get locale for translations
+        Get locale for page translations
     """
     return app.config.get(u'LANGUAGE')
 
 
 @app.template_filter('date')
 def date_filter(date, format = None) :
+    """
+        Date filter to use in Jinja2 templates
+
+        :param date : datetime object to convert
+        :param format: format to convert date object
+        :type date: datetime
+        :type format: str
+
+        .. warnings:: Format is in flask.ext.babel format
+    """
     if date :
         if format :
             return format_datetime(date, format)
@@ -62,8 +74,14 @@ def date_filter(date, format = None) :
 
 @app.before_request
 def before_request() :
-    # posts list
-    contents = [Content.from_page(p) for p in pages]
+    """
+        Refresh global vars before each requests
+    """
+    # update config
+    path = app.config['SHELVE_FILENAME']
+    db = shelve.open(path)
+    app.config.update(db)
+    # posts list    
     g.posts  = sorted(
                 [c for c in contents if c.content_type == 'posts' 
                 and not c.draft],
@@ -80,33 +98,75 @@ def before_request() :
     # search form
     if not hasattr(g, 'search_form') : 
         g.search_form = SearchForm()
+    # close db
+    db.close()
 
 
 @app.route('/')
 def index():
     """
-    List of blog posts summaries
+        Main page of the app
+
+        List of blog posts summaries
+    """
+    # theme
+    default = app.config['DEFAULT_THEME']
+    theme = app.config.get(u'THEME', default)
+    # per page
+    per_page = app.config['PAGINATION']
+    return render_theme_paginated('index.html', theme, g.posts, per_page,
+                                    request) 
+
+
+@app.route('/sitemaps.xml')
+def sitemap() :
+    """
+        Site sitemap
+    """
+    # list all contents
+    sitemap_contents = [c for c in contents if not c.draft]
+    sitemap = render_template('sitemap.xml', contents = sitemap_contents)
+    response = make_response(sitemap)
+    response.headers['Content-Type'] = 'application/xml'
+    return response
+
+
+@app.route('/favicon.ico')
+def favicon() :
+    """
+        App favicon
+    """
+    default = app.config['DEFAULT_THEME']
+    theme_id = app.config.get(u'THEME', default)
+    theme = get_theme(theme_id)
+    path = os.path.join(theme.static_path, 'img', 'favicon.png')
+    if os.path.exists(path) :
+        url = static_file_url(theme, 'img/favicon.png')
+    else :
+        url = url_for('static', filename='img/favicon.png')
+    return redirect(url)
+
+@app.route('/robots.txt')
+def robots() :
+    """
+        App robots.txt
     """
-    # pagination
     try :
-        page = int(request.args.get('page', 1))
-    except ValueError :
-        page = 1
-    per_page = app.config[u'PAGINATION']    
-    pagination = create_pagination(page, per_page, g.posts)
-    # get content for current page
-    displayed = get_objects_for_page(page, per_page, g.posts)
-    # override page to have summary
-    return render('index.html', pages=displayed, pagination=pagination)
+        url = url_for('static', filename='media/robots.txt')
+        return redirect(url) 
+    except :
+        abort(404)
 
 
 @app.route('/<path:path>/', methods = ['GET', 'POST'])
 def page(path):
     """
-    Access page from path
+        Get access for page from its path.
+        If path is not valid it will return a 404 error page
+
+        :param path: Valid content path 
     """    
-    page = pages.get_or_404(path)
-    content = Content.from_page(page)
+    content = contents.get_or_404(path)
     form = None
     # enable comments for posts only
     if content.content_type == 'posts' :
@@ -122,69 +182,61 @@ def page(path):
 @app.route('/category/<category>')
 def category(category) :
     """
-    Filter posts by category
+        Filter posts by category
+
+        :param category: Category to filter contents
+        :type category: str
     """
     posts = [p for p in g.posts if p.category == category]
-    # pagination
-    try :
-        page = int(request.args.get('page', 1))
-    except ValueError :
-        page = 1
-    per_page = app.config[u'PAGINATION']    
-    pagination = create_pagination(page, per_page, posts)
-    # get content for current page
-    displayed = get_objects_for_page(page, per_page, posts)
-    return render('index.html', title = category, pages = displayed,
-            pagination = pagination)
+    # theme
+    default = app.config['DEFAULT_THEME']
+    theme = app.config.get(u'THEME', default)
+    # per page
+    per_page = app.config['PAGINATION']
+    return render_theme_paginated('index.html', theme, posts, per_page,
+                                    request, title=category)
 
 
 @app.route('/tag/<tag>')
 def tag(tag) :
     """
-    Filter posts by tag
+        Filter posts by tag
+
+        :param tag: Category to filter contents
+        :type tag: str
     """
     posts = [p for p in g.posts if tag in p.tags.split(',')]
-    # pagination
-    try :
-        page = int(request.args.get('page', 1))
-    except ValueError :
-        page = 1
-    per_page = app.config[u'PAGINATION']    
-    pagination = create_pagination(page, per_page, posts)
-    # get content for current page
-    displayed = get_objects_for_page(page, per_page, posts)
-    return render('index.html', title = tag, pages = displayed,
-            pagination = pagination)
+    # theme
+    default = app.config['DEFAULT_THEME']
+    theme = app.config.get(u'THEME', default)
+    # per page
+    per_page = app.config['PAGINATION']
+    return render_theme_paginated('index.html', theme, posts, per_page,
+                                    request, title=tag)
 
 
 @app.route('/archives')
 def archives() :
     """
-    Page listing all contents
+       List all contents order by reverse date
     """
     # sort pages by reverse date
     sorted_pages = sorted(
-                        [Content.from_page(p) for p in pages],
+                        contents,
                         key = lambda x : x.published,
                         reverse = True
                     )
-    # pagination
-    try :
-        page = int(request.args.get('page', 1))
-    except ValueError :
-        page = 1
-    per_page = 10   
-    pagination = create_pagination(page, per_page, sorted_pages)
-    # get content for current page
-    displayed = get_objects_for_page(page, per_page, sorted_pages)
-    return render('archive.html',  pages = displayed, 
-            pagination = pagination)
+    # theme
+    default = app.config['DEFAULT_THEME']
+    theme = app.config.get(u'THEME', default)
+    return render_theme_paginated('archive.html', theme, sorted_pages, 10,
+                                    request)
 
 
 @app.route('/search/', methods = ['POST'])
 def search() :
     """
-    Search in contents
+        Search in contents
     """
     if not g.search_form.validate_on_submit() :
         return redirect(url_for('index'))
@@ -197,24 +249,17 @@ def search() :
                             reverse = True
                        )
     # pagination
-    try :
-        page = int(request.args.get('page', 1))
-    except ValueError :
-        page = 1
-    per_page = 20    
-    pagination = create_pagination(page, per_page, sorted_contents)
-    # get content for current page
-    displayed = get_objects_for_page(page, per_page, sorted_contents)
-    return render('index.html', title = query, pages = displayed,
-            pagination = pagination)
+    # theme
+    default = app.config['DEFAULT_THEME']
+    theme = app.config.get(u'THEME', default)
+    return render_theme_paginated('index.html', theme, sorted_contents, 
+                                    10, request, title=query)
 
     
-
-
 @app.route('/feed.atom')
 def feed() :
     """
-    Generate feeds
+        Generate 20 last content atom feed
     """
     if app.config.get('RSS', 'NO') != 'YES' :
         abort(404)
@@ -226,38 +271,6 @@ def feed() :
                 unicode(post.summary),
                 content_type = 'html',
                 author = post.meta.get('author', ''),
-                url = url_for('page', path = post.path, _external = True),
+                url = urljoin(request.url_root, post.path),
                 updated = post.published)
     return feed.get_response()
-
-
-@clize
-def run_server(port = 8000, ip = '127.0.0.1') :
-    """
-    Run Microbe app on Cherrypy server
-
-    port: Server socket port
-
-    ip: Server socket host
-    """
-    import cherrypy
-    from paste.translogger import TransLogger
-    # enable paste logging
-    app_logged = TransLogger(app)
-    # mount the wsgi callable object on the root dir
-    cherrypy.tree.graft(app_logged, '/')
-    # set cherrypy config
-    cherrypy.config.update({
-        'engine.autoreload_on' : True,
-        'log.screen' : True,
-        'server.socket_port' : port,
-        'server.socket_host' : ip
-    })
-    # start server
-    cherrypy.engine.start()
-    cherrypy.engine.block()
-
-
-def main() :
-    init_index()
-    run(run_server)
